@@ -3,12 +3,14 @@
 
 """Šis ir testa skripts"""
 
-def paradit_listi(liste):
+def paradit_listi(liste, limenis):
 
 	"""Funkcijas kaut ko dara, bet es aizmirsu ko"""
 
 	for maz_liste in liste:
 		if isinstance(maz_liste, list):
-			paradit_listi(maz_liste)
+			paradit_listi(maz_liste, limenis + 1)
 		else:
+			for tab in range(limenis):
+				print("\t", end="")
 			print(maz_liste)
